@@ -2,7 +2,7 @@ from pathlib import Path
 from rich import print
 import os
 import subprocess as sp
-import helpers as hp
+from pnpm import helpers as hp
 
 # helpers
 def _params(length=3):
